package de.trion.microservices.takeorder;


import de.trion.microservices.avro.Order;
import io.confluent.kafka.streams.serdes.avro.SpecificAvroSerializer;
import java.util.Properties;
import java.util.UUID;
import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.common.serialization.UUIDSerializer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;


@SpringBootApplication
@EnableConfigurationProperties(ApplicationProperties.class)
public class Application
{
  private final static Logger LOG = LoggerFactory.getLogger(Application.class);


  @Bean(destroyMethod = "close")
  KafkaProducer<UUID,Order> producer(ApplicationProperties properties)
  {
    Properties props = new Properties();
    props.put("bootstrap.servers", properties.bootstrapServers);
    props.put("schema.registry.url", properties.schemaRegistryUrl);
    props.put("key.serializer", UUIDSerializer.class.getName());
    props.put("value.serializer", SpecificAvroSerializer.class.getName());

    return new KafkaProducer<>(props);
  }

  public static void main(String[] args)
  {
    SpringApplication.run(Application.class, args);
  }
}